@@ -158,14 +158,6 @@ const TelepathyClient = new Lang.Class({
         this._chatSources[channel.get_object_path()] = source;
         source.connect('destroy', Lang.bind(this,
                        function() {
-                           if (this._tpClient.is_handling_channel(channel)) {
-                               // The chat box has been destroyed so it can't
-                               // handle the channel any more.
-                               channel.close_async(function(src, result) {
-                                   channel.close_finish(result);
-                               });
-                           }
-
                            delete this._chatSources[channel.get_object_path()];
                        }));
     },
@@ -274,13 +266,6 @@ const ChatSource = new Lang.Class({
         this._channel = channel;
         this._closedId = this._channel.connect('invalidated', Lang.bind(this, this._channelClosed));
 
-        this._notification = new ChatNotification(this);
-        this._notification.connect('activated', Lang.bind(this, this.open));
-        this._notification.connect('updated', Lang.bind(this,
-            function() {
-                if (this._banner && this._banner.expanded)
-                    this._ackMessages();
-            }));
         this._notifyTimeoutId = 0;
 
         this._presence = contact.get_presence_type();
@@ -295,11 +280,28 @@ const ChatSource = new Lang.Class({
 
         // Add ourselves as a source.
         Main.messageTray.add(this);
-        this.pushNotification(this._notification);
 
         this._getLogMessages();
     },
 
+    _ensureNotification: function() {
+        if (this._notification)
+            return;
+
+        this._notification = new ChatNotification(this);
+        this._notification.connect('activated', Lang.bind(this, this.open));
+        this._notification.connect('updated', Lang.bind(this,
+            function() {
+                if (this._banner && this._banner.expanded)
+                    this._ackMessages();
+            }));
+        this._notification.connect('destroy', Lang.bind(this,
+            function() {
+                this._notification = null;
+            }));
+        this.pushNotification(this._notification);
+    },
+
     _createPolicy: function() {
         return new MessageTray.NotificationApplicationPolicy('empathy');
     },
@@ -326,7 +328,8 @@ const ChatSource = new Lang.Class({
             return;
 
         this.setTitle(newAlias);
-        this._notification.appendAliasChange(oldAlias, newAlias);
+        if (this._notification)
+            this._notification.appendAliasChange(oldAlias, newAlias);
     },
 
     getIcon: function() {
@@ -369,9 +372,10 @@ const ChatSource = new Lang.Class({
 
     _updateAvatarIcon: function() {
         this.iconUpdated();
-        this._notification.update(this._notification.title,
-                                  this._notification.bannerBodyText,
-                                  { gicon: this.getIcon() });
+        if (this._notifiction)
+            this._notification.update(this._notification.title,
+                                      this._notification.bannerBodyText,
+                                      { gicon: this.getIcon() });
     },
 
     open: function() {
@@ -412,6 +416,7 @@ const ChatSource = new Lang.Class({
         let [success, events] = logManager.get_filtered_events_finish(result);
 
         let logMessages = events.map(makeMessageFromTplEvent);
+        this._ensureNotification();
 
         let pendingTpMessages = this._channel.get_pending_messages();
         let pendingMessages = [];
@@ -461,6 +466,18 @@ const ChatSource = new Lang.Class({
     },
 
     destroy: function(reason) {
+        if (this._client.is_handling_channel(this._channel)) {
+            // The chat box has been destroyed so it can't
+            // handle the channel any more.
+            this._channel.close_async(function(channel, result) {
+                channel.close_finish(result);
+            });
+        }
+
+        // Keep source alive while the channel is open
+        if (reason != MessageTray.NotificationDestroyedReason.SOURCE_CLOSED)
+            return;
+
         if (this._destroyed)
             return;
 
@@ -474,9 +491,6 @@ const ChatSource = new Lang.Class({
         this._contact.disconnect(this._notifyAvatarId);
         this._contact.disconnect(this._presenceChangedId);
 
-        if (this._timestampTimeoutId)
-            Mainloop.source_remove(this._timestampTimeoutId);
-
         this.parent(reason);
     },
 
@@ -501,6 +515,7 @@ const ChatSource = new Lang.Class({
         if (message.get_message_type() == Tp.ChannelTextMessageType.DELIVERY_REPORT)
             return;
 
+        this._ensureNotification();
         this._pendingMessages.push(message);
         this.countUpdated();
 
@@ -528,6 +543,7 @@ const ChatSource = new Lang.Class({
     // This is called for both messages we send from
     // our client and other clients as well.
     _messageSent: function(channel, message, flags, token) {
+        this._ensureNotification();
         message = makeMessageFromTpMessage(message, NotificationDirection.SENT);
         this._notification.appendMessage(message);
     },
@@ -565,9 +581,10 @@ const ChatSource = new Lang.Class({
     },
 
     _presenceChanged: function (contact, presence, status, message) {
-        this._notification.update(this._notification.title,
-                                  this._notification.bannerBodyText,
-                                  { secondaryGIcon: this.getSecondaryIcon() });
+        if (this._notification)
+            this._notification.update(this._notification.title,
+                                      this._notification.bannerBodyText,
+                                      { secondaryGIcon: this.getSecondaryIcon() });
     },
 
     _pendingRemoved: function(channel, message) {
@@ -577,6 +594,10 @@ const ChatSource = new Lang.Class({
             this._pendingMessages.splice(idx, 1);
             this.countUpdated();
         }
+
+        if (this._pendingMessages.length == 0 &&
+            this._banner && !this._banner.expanded)
+            this._banner.hide();
     },
 
     _ackMessages: function() {
@@ -600,6 +621,13 @@ const ChatNotification = new Lang.Class({
         this._timestampTimeoutId = 0;
     },
 
+    destroy: function(reason) {
+        if (this._timestampTimeoutId)
+            Mainloop.source_remove(this._timestampTimeoutId);
+        this._timestampTimeoutId = 0;
+        this.parent(reason);
+    },
+
     /**
      * appendMessage:
      * @message: An object with the properties:
@@ -682,6 +710,7 @@ const ChatNotification = new Lang.Class({
         // Reset the old message timeout
         if (this._timestampTimeoutId)
             Mainloop.source_remove(this._timestampTimeoutId);
+        this._timestampTimeoutId = 0;
 
         let message = { realMessage: props.group != 'meta',
                         showTimestamp: false };
@@ -830,6 +859,10 @@ const ChatNotificationBanner = new Lang.Class({
             adjustment.value = adjustment.upper;
     },
 
+    hide: function() {
+        this.emit('done-displaying');
+    },
+
     _addMessage: function(message) {
         let highlighter = new Calendar.URLHighlighter(message.body, true, true);
         let body = highlighter.actor;
