@@ -115,6 +115,39 @@ const WindowMenu = new Lang.Class({
             }
         }
 
+        let screen = global.screen;
+        let nMonitors = screen.get_n_monitors();
+        if (nMonitors > 1) {
+          this.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());
+
+          let monitorIndex = window.get_monitor();
+
+          let upMonitorIndex = screen.get_monitor_neighbor_index(monitorIndex, Meta.ScreenDirection.UP);
+          if (upMonitorIndex != -1) {
+            this.addAction(_("Move to Monitor Up"), Lang.bind(this, function(event) {
+              window.move_to_monitor(upMonitorIndex);
+            }));
+          }
+          let downMonitorIndex = screen.get_monitor_neighbor_index(monitorIndex, Meta.ScreenDirection.DOWN);
+          if (downMonitorIndex != -1) {
+            this.addAction(_("Move to Monitor Down"), Lang.bind(this, function(event) {
+              window.move_to_monitor(downMonitorIndex);
+            }));
+          }
+          let leftMonitorIndex = screen.get_monitor_neighbor_index(monitorIndex, Meta.ScreenDirection.LEFT);
+          if (leftMonitorIndex != -1) {
+            this.addAction(_("Move to Monitor Left"), Lang.bind(this, function(event) {
+              window.move_to_monitor(leftMonitorIndex);
+            }));
+          }
+          let rightMonitorIndex = screen.get_monitor_neighbor_index(monitorIndex, Meta.ScreenDirection.RIGHT);
+          if (rightMonitorIndex != -1) {
+            this.addAction(_("Move to Monitor Right"), Lang.bind(this, function(event) {
+              window.move_to_monitor(rightMonitorIndex);
+            }));
+          }
+        }
+
         this.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());
 
         item = this.addAction(_("Close"), Lang.bind(this, function(event) {
@@ -167,10 +200,6 @@ const WindowMenuManager = new Lang.Class({
         menu.connect('activate', function() {
             window.check_alive(global.get_current_time());
         });
-        let destroyId = window.connect('unmanaged',
-            function() {
-                menu.close();
-            });
 
         this._sourceActor.set_size(rect.width, rect.height);
         this._sourceActor.set_position(rect.x, rect.y);
@@ -184,7 +213,6 @@ const WindowMenuManager = new Lang.Class({
 
             this._sourceActor.hide();
             menu.destroy();
-            window.disconnect(destroyId);
         }));
     }
 });
